<?php

/**
 * Classe plxAdmin responsable des modifications dans l'administration
 *
 * @package PLX
 * @author	Anthony GUÉRIN, Florent MONTHEL et Stephane F
 **/
class plxAdmin extends plxMotor {

	/**
	 * Constructeur qui appel le constructeur parent
	 *
	 * @param	filename	emplacement du fichier XML de configuration
	 * @return	null
	 * @author	Florent MONTHEL
	 **/
	function plxAdmin($filename) {

		parent::plxMotor($filename);
	}

	/**
	 * Méthode qui édite le fichier XML e configuration selon le tableau $global et $content
	 *
	 * @param	global	tableau contenant toute la configuration Pluxml
	 * @param	content	tableau contenant la configuration à modifier
	 * @return	string
	 * @author	Florent MONTHEL
	 **/
	function editConfiguration($global,$content) {

		# Tableau des clés à mettre sous chaîne cdata
		$aCdata = array('title','description','racine');
		# Début du fichier XML
		$xml = "<?xml version='1.0' encoding='".PLX_CHARSET."'?>\n";
		$xml .= "<document>\n";
		foreach($content as $k=>$v) {
			$global[ $k ] = $v;
		}
		foreach($global as $k=>$v) {
			if(in_array($k,$aCdata))
				$xml .= "\t<parametre name=\"$k\"><![CDATA[".$v."]]></parametre>\n";
			else
				$xml .= "\t<parametre name=\"$k\">".$v."</parametre>\n";
		}
		$xml .= "</document>";
		# On écrit le fichier
		if(plxUtils::write($xml,PLX_CONF))
			return 'Configuration modifi&eacute;e &agrave; '.date('H:m:s');
		else
			return 'Erreur dans la modification du fichier '.PLX_CONF;
	}

	/**
	 * Méthode qui parse le fichier des mots de passe
	 *
	 * @param	filename	emplacement du fichier XML des passwd
	 * @return	array	tableau login mot de passe array(login) = mdp(md5)
	 * @author	Florent MONTHEL
	 **/
	function getPasswd($filename) {

		# Mise en place du parseur XML
		$data = implode('',file($filename));
		$parser = xml_parser_create(PLX_CHARSET);
		xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
		xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
		xml_parse_into_struct($parser,$data,$values,$iTags);
		xml_parser_free($parser);
		$array = array();
		# On verifie qu'il existe des tags "user"
		if(isset($iTags['user'])) {
			# On compte le nombre de tags "user"
			$nb = count($iTags['user']);
			# On boucle sur $nb
			for($i = 0; $i < $nb; $i++) {
				$array[ $values[ $iTags['user'][$i] ]['attributes']['login'] ] = $values[ $iTags['user'][$i] ]['value'];
			}
		}
		# On retourne le tableau
		return $array;
	}

	/**
	 * Méthode qui édite le fichier XML du rédacteur (password+login) selon le tableau $content
	 *
	 * @param	content	tableau des informations sur le rédacteur
	 * @return	string
	 * @author	Florent MONTHEL
	 **/
	function editRedacteur($content) {

		# Contrôle des données
		if(trim($content['login']) == '' OR trim($content['pwd']) == '')
			return 'Merci de remplir tous les champs';
		if(trim($content['pwd']) != trim($content['pwd2']))
			return 'Le mot de passe et sa confirmation ne sont pas identiques';
		
		# Génération du fichier XML
		$xml = "<?xml version='1.0' encoding='".PLX_CHARSET."'?>\n";
		$xml .= "<document>\n";
		$xml .= "\t".'<user login="'.trim($content['login']).'">'.md5(trim($content['pwd'])).'</user>'."\n";
		$xml .= "</document>";
		
		# On écrit le fichier
		if(plxUtils::write($xml,PLX_ROOT.$this->aConf['passwords'])) {
			# On modifie les variables de sessions
			$_SESSION['author'] = trim($content['login']);
			$_SESSION['pass'] = md5(trim($content['pwd']));
			# On sort
			return 'Compte r&eacute;dacteur modifi&eacute; &agrave; '.date('H:m:s');
		} else {
			return 'Erreur dans la modification du fichier '.PLX_ROOT.$this->aConf['passwords'];
		}
	}

	/**
	 * Méthode qui vérifie sur le site de Pluxml la dernière version et la compare avec celle en local
	 *
	 * @return	string
	 * @author	Florent MONTHEL
	 **/
	function checkMaj() {

		# La fonction est active ?
		if(!ini_get('allow_url_fopen'))
			return 'Impossible de v&eacute;rifier les mises &agrave; jour tant que \'allow_url_fopen\' est d&eacute;sactiv&eacute; sur ce syst&egrave;me';
		
		# Requete HTTP sur le site de Pluxml
		$fp = @fopen('http://pluxml.org/blog-latest-version', 'r');
		$latest_version = trim(@fread($fp, 16));
		@fclose($fp);
		
		if($latest_version == '')
			return 'La v&eacute;rification de mise &agrave; jour a &eacute;chou&eacute;e pour une raison inconnue';
		
		$cur_version = str_replace(array('.','alpha','blog','dev','beta','rc',' '), '', strtolower($this->version));
		$cur_version = (strlen($cur_version) == 2) ? intval($cur_version) * 10 : intval($cur_version);
		$latest_version = str_replace(array('.','alpha','blog','dev','beta','rc',' '), '', strtolower($latest_version));
		$latest_version = (strlen($latest_version) == 2) ? intval($latest_version) * 10 : intval($latest_version);
		
		if($cur_version >= $latest_version)
			return 'Vous utilisez la derni&egrave;re version de Pluxml ('.$this->version.')';
		else
		 return 'Une nouvelle version de Pluxml est sortie ! Vous pouvez la t&eacute;l&eacute;charger sur <a href="http://pluxml.org/">Pluxml.org</a>';
	}

	/**
	 * Méthode qui édite le fichier XML des catégories selon le tableau $content
	 *
	 * @param	content	tableau multidimensionnel des catégories
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/
	function editCategories($content) {

		# Début du fichier XML
		$xml = "<?xml version=\"1.0\" encoding=\"".PLX_CHARSET."\"?>\n";
		$xml .= "<document>\n";
		# On va trier les clés selon l'ordre choisi
		foreach($content as $k=>$v) {
			if(is_numeric($k))
				$array[$k] = $content[$k.'_ordre'];
		}
		asort($array);
		# On va générer l'entrée XML pour chaque catégorie
		foreach($array as $k=>$v) {
			$cat_num = $k;
			$cat_name = trim($content[$k]);
			if ($cat_name != '') {
				$cat_url = (isset($content[$k.'_url']))?trim($content[$k.'_url']):'';
				$cat_tri = $content[$k.'_tri'];
				$cat_bypage = intval($content[$k.'_bypage']);
				if($cat_url != '')
					$cat_url = plxUtils::title2url($cat_url);
				else
					$cat_url = plxUtils::title2url($cat_name);
				# On génère notre ligne
				$xml .= "\t<categorie number=\"".$cat_num."\" tri=\"".$cat_tri."\" bypage=\"".$cat_bypage."\" url=\"".$cat_url."\"><![CDATA[".$cat_name."]]></categorie>\n";
			}
		}
		$xml .= "</document>";
		# On écrit le fichier
		if(plxUtils::write($xml,PLX_ROOT.$this->aConf['categories']))
			return 'Cat&eacute;gories modifi&eacute;es &agrave; '.date('H:m:s');
		else
			return 'Erreur dans la modification du fichier '.PLX_ROOT.$this->aConf['categories'];
	}

	/**
	 * Méthode qui édite le fichier XML des pages statiques selon le tableau $content
	 *
	 * @param	content	tableau multidimensionnel des pages statiques
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/
	function editStatiques($content) {

		# Début du fichier XML
		$xml = "<?xml version=\"1.0\" encoding=\"".PLX_CHARSET."\"?>\n";
		$xml .= "<document>\n";
		# On va trier les clés selon l'ordre choisi
		foreach($content as $k=>$v) {
			if(is_numeric($k))
				$array[$k] = $content[$k.'_ordre'];
		}
		asort($array);
		# On va générer l'entrée XML pour chaque page statique
		foreach($array as $k=>$v) {
			$stat_num = $k;
			$stat_name = trim($content[$k]);
			if($stat_name != '') {
				$stat_url = (isset($content[$k.'_url']))?trim($content[$k.'_url']):'';
				$stat_active = intval($content[$k.'_active']);
				if($stat_url != '')
					$stat_url = plxUtils::title2url($stat_url);
				else
					$stat_url = plxUtils::title2url($stat_name);
				# On va vérifier si on a besoin de renommer la page statique
				if(isset($this->aStats[ $stat_num ]) AND $this->aStats[ $stat_num ]['url'] != $stat_url) {
					if(file_exists(PLX_ROOT.$this->aConf['racine_statiques'].$stat_num.'.'.$this->aStats[ $stat_num ]['url'].'.php'))
						@rename(PLX_ROOT.$this->aConf['racine_statiques'].$stat_num.'.'.$this->aStats[ $stat_num ]['url'].'.php',PLX_ROOT.$this->aConf['racine_statiques'].$stat_num.'.'.$stat_url.'.php');
				}
				# On génère notre ligne
				$xml .= "\t<statique number=\"".$stat_num."\" active=\"".$stat_active."\" url=\"".$stat_url."\"><![CDATA[".$stat_name."]]></statique>\n";
			} else { # On supprime la ligne donc le fichier de la page statique
				if(isset($this->aStats[ $stat_num ]) AND file_exists(PLX_ROOT.$this->aConf['racine_statiques'].$stat_num.'.'.$this->aStats[ $stat_num ]['url'].'.php'))
					@unlink(PLX_ROOT.$this->aConf['racine_statiques'].$stat_num.'.'.$this->aStats[ $stat_num ]['url'].'.php');
			}
		}
		$xml .= "</document>";
		# On écrit le fichier
		if(plxUtils::write($xml,PLX_ROOT.$this->aConf['statiques']))
			return 'Pages statiques modifi&eacute;es &agrave; '.date('H:m:s');
		else
			return 'Erreur dans la modification du fichier '.PLX_ROOT.$this->aConf['statiques'];
	}

	/**
	 * Méthode qui lit le fichier d'une page statique
	 *
	 * @param	num	numero du fichier de la page statique
	 * @return	string	contenu de la page
	 * @author	Stephane F.
	 **/
	function getFileStatique($num) {

		# Emplacement de la page
		$filename = PLX_ROOT.$this->aConf['racine_statiques'].$num.'.'.$this->aStats[ $num ]['url'].'.php';
		if(file_exists($filename) AND filesize($filename) > 0) {
			if($f = fopen($filename, 'r')) {
				$content = fread($f, filesize($filename));
				fclose($f);
				# On retourne le contenu
				return $content;
			}
		}
		return null;
	}

	/**
	 * Méthode qui sauvegarde le contenu d'une page statique
	 *
	 * @param	content	données à sauvegarder
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/
	function editFileStatique($content) {

		# Génération du nom du fichier
		$filename = PLX_ROOT.$this->aConf['racine_statiques'].$content['id'].'.'.$this->aStats[ $content['id'] ]['url'].'.php';
		# On écrit le fichier
		if(plxUtils::write($content['content'],$filename))
			return 'Code source de la page statique modifi&eacute; &agrave; '.date('H:m:s');
		else
			return 'Erreur dans la modification du fichier '.$filename;
	}

	/**
	 *  Méthode qui retourne le prochain id d'un article
	 *
	 * @return	int
	 * @author	Stephane F.
	 **/		
	function nextIdArticle() {

		if (!$aFiles = $this->plxGlob_arts->query('/^[0-9{4}].(.*).xml$/', '', 'rsort', 0, 1))
			return '0001';
		return str_pad($this->artInfoFromFilename($aFiles['0'],'artId')+1,4, '0', STR_PAD_LEFT);
	}
	
	/**
	 * Méthode qui effectue une création ou mise a jour d'un article
	 *
	 * @param	content	données saisies de l'article
	 * @param	&id	retourne le numero de l'article 
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/	
	function editArticle($content, &$id) {

		# Détermine le numero de fichier si besoin est
		if($id == '0000' OR $id == '')
			$id = $this->nextIdArticle();
		# Vérification de l'intégrité de l'identifiant
		if(!preg_match('/^[0-9]{4}$/',$id))
			return 'Identifiant d\'article invalide !';
		# Génération de notre url d'article
		if(trim($content['url']) == '')
			$content['url'] = plxUtils::title2url($content['title']);
		else
			$content['url'] = plxUtils::title2url($content['url']);
		# Génération du fichier XML
		$xml = "<?xml version='1.0' encoding='".PLX_CHARSET."'?>\n";
		$xml .= "<document>\n";
		$xml .= "\t".'<infopost>'."\n";
		$xml .= "\t\t".'<title><![CDATA['.trim($content['title']).']]></title>'."\n";
		$xml .= "\t\t".'<author><![CDATA['.$_SESSION['author'].']]></author>'."\n";
		$xml .= "\t\t".'<allow_com>'.$content['allow_com'].'</allow_com>'."\n";
		$xml .= "\t".'</infopost>'."\n";
		$xml .= "\t".'<chapo><![CDATA['.trim($content['chapo']).']]></chapo>'."\n";
		$xml .= "\t".'<content><![CDATA['.trim($content['content']).']]></content>'."\n";
		$xml .= "</document>\n";
		
		# A t'on besoin de supprimer un fichier ?
		if($globArt = $this->plxGlob_arts->query('/^'.$id.'.(.*).xml$/','','sort',0,1)) {
			if(file_exists(PLX_ROOT.$this->aConf['racine_articles'].$globArt['0'])) # Un fichier existe, on le supprime
				@unlink(PLX_ROOT.$this->aConf['racine_articles'].$globArt['0']);
		}
		# On genère le nom de notre fichier
		$time = $content['year'].$content['month'].$content['day'].substr(str_replace(':','',$content['time']),0,4);
		if(!preg_match('/^[0-9]{12}$/',$time)) $time = date('YmdHi'); # Check de la date au cas ou...
		$filename = PLX_ROOT.$this->aConf['racine_articles'].$id.'.'.$content['catId'].'.'.$time.'.'.$content['url'].'.xml';
		# On va mettre à jour notre fichier
		if(plxUtils::write($xml,$filename)) {
			if($content['artId'] == '0000' OR $content['artId'] == '')
				return 'Article cr&eacute;&eacute; &agrave; '.date('H:m:s');
			else
				return 'Article mis &agrave; jour &agrave; '.date('H:m:s');
		} else {
			return 'Erreur lors de la sauvegarde de l\'article';
		}
	}

	/**
	 * Méthode qui supprime un article et les commentaires associés
	 *
	 * @param	id	numero de l'article à supprimer
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/
	function delArticle($id) {

		# Vérification de l'intégrité de l'identifiant
		if(!preg_match('/^[0-9]{4}$/',$id))
			return 'Identifiant d\'article invalide !';
		# Variable d'état
		$resDelArt = $resDelCom = true;
		# Suppression de l'article
		if($globArt = $this->plxGlob_arts->query('/^'.$id.'.(.*).xml$/')) {
			@unlink(PLX_ROOT.$this->aConf['racine_articles'].$globArt['0']);
			$resDelArt = !file_exists(PLX_ROOT.$this->aConf['racine_articles'].$globArt['0']);
		}
		# Suppression des commentaires
		if($globComs = $this->plxGlob_coms->query('/^_?'.$id.'.(.*).xml$/')) {
			for($i=0; $i<$this->plxGlob_coms->count; $i++) {
				@unlink(PLX_ROOT.$this->aConf['racine_commentaires'].$globComs[$i]);
				$resDelCom = (!file_exists(PLX_ROOT.$this->aConf['racine_commentaires'].$globComs[$i]) AND $resDelCom);
			}
		}
		# On renvoi le résultat
		if($resDelArt AND $resDelCom)
			return 'Article supprim&eacute; &agrave; '.date('H:m:s');
		else
			return 'L\'article n\'a pas pu &ecirc;tre supprim&eacute; compl&egrave;tement';
	}

	/**
	 * Méthode qui effectue une mise a jour d'un commentaire
	 *
	 * @param	content	données du commentaire à mettre à jour
	 * @param	id	identifiant du commentaire
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/		
	function editCommentaire($content, $id) {

		# Génération du nom du fichier
		$filename = PLX_ROOT.$this->aConf['racine_commentaires'].$id.'.xml';
		if(!file_exists($filename)) # Commentaire inexistant
			return 'Le commentaire demand&eacute; n\'existe pas ou n\'existe plus';
		# On récupère les infos du commentaire
		$com = $this->parseCommentaire($filename);
		# On le remplace
		$content['content'] = htmlspecialchars($content['content'],ENT_QUOTES,PLX_CHARSET);
		$this->delCommentaire($id);
		$this->addCommentaire($filename,$com['author'],$com['ip'],$com['mail'],$com['site'],$content['content']);
		if(is_readable($filename))
			return 'Le commentaire a &eacute;t&eacute; modifi&eacute; &agrave; '.date('H:m:s');
		else
			return 'Erreur lors de la mise &agrave; jour du commentaire';
	}
	
	/**
	 * Méthode qui supprime un commentaire
	 *
	 * @param	id	identifiant du commentaire à supprimer
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/	
	function delCommentaire($id) {
	
		# Génération du nom du fichier
		$filename = PLX_ROOT.$this->aConf['racine_commentaires'].$id.'.xml';
		# Suppression du commentaire
		if(file_exists($filename)) {
			@unlink($filename);
		}
		if(!file_exists($filename))
			return 'Commentaire supprim&eacute &agrave; '.date('H:m:s');
		else
			return 'Erreur lors de la suppression du commentaire';
	}
	
	/**
	 * Méthode qui permet de modérer ou valider un commentaire
	 *
	 * @param	id	identifiant du commentaire à traiter (que l'on retourne)
	 * @return	string
	 * @author	Stephane F. et Florent MONTHEL
	 **/	
	function modCommentaire(&$id) {
	
		# Génération du nom du fichier
		$oldfilename = PLX_ROOT.$this->aConf['racine_commentaires'].$id.'.xml';
		if(!file_exists($oldfilename)) # Commentaire inexistant
			return 'Le commentaire demand&eacute; n\'existe pas ou n\'existe plus';
		# Modérer ou valider ?
		if(preg_match('/^_/',$id)) {
			$type = 'val';
			$id = str_replace('_', '', $id);
		} else {
			$type = 'mod';
			$id = '_'.$id;
		}
		# Génération du nouveau nom de fichier
		$newfilename = PLX_ROOT.$this->aConf['racine_commentaires'].$id.'.xml';
		# On renomme le fichier
		@rename($oldfilename,$newfilename);
		# Contrôle
		if(is_readable($newfilename)) {
			if($type == 'val')
				return 'Le commentaire a &eacute;t&eacute; valid&eacute; &agrave; '.date('H:m:s');
			else
				return 'Le commentaire a &eacute;t&eacute; mis hors ligne &agrave; '.date('H:m:s');
		} else {
			if($type == 'val')
				return 'Erreur lors de la validation du commentaire';
			else
				return 'Erreur lors de la mod&eacute;ration du commentaire';
		}	
	}

}
?>