<?php

/**
 * Classe plxShow responsable de l'affichage sur stdout
 *
 * @package PLX
 * @author	Florent MONTHEL
 **/
class plxShow {

	var $plxMotor = false; # Objet plxMotor

	/**
	 * Constructeur qui initialise l'objet plxMotor par rfrence
	 *
	 * @param	plxMotor	objet plxMotor pass par rfrence
	 * @return	null
	 * @author	Florent MONTHEL
	 **/
	function plxShow(&$plxMotor) {

		$this->plxMotor = &$plxMotor;
	}

	/**
	 * Mthode qui affiche le charset selon la casse $casse
	 *
	 * @param	casse	casse min ou maj
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function charset($casse='min') {

		if($casse != 'min') # En majuscule
			echo strtoupper(PLX_CHARSET);
		else # En minuscule
			echo strtolower(PLX_CHARSET);
	}

	/**
	 * Mthode qui affiche la version de Pluxml
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function version() {

		echo $this->plxMotor->version;
	}

	/**
	 * Mthode qui affiche la variable get de l'objet plxMotor (variable $_GET globale)
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function get() {

		echo $this->plxMotor->get;
	}

	/**
	 * Mthode qui affiche le temps d'excution de la page
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function chrono() {

		echo round(plxUtils::microtime()-$this->plxMotor->start,3).'s';
	}

	/**
	 * Mthode qui affiche le dossier de stockage du style actif
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function template() {

		echo PLX_ROOT.'themes/'.$this->plxMotor->style;
	}

	/**
	 * Mthode qui affiche le titre de la page selon le mode
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function pageTitle() {

		if($this->plxMotor->mode == 'home') {
			echo htmlspecialchars($this->plxMotor->aConf['title'].' - '.$this->plxMotor->aConf['description'],ENT_QUOTES,PLX_CHARSET);
			return;
		}
		if($this->plxMotor->mode == 'categorie') {
			echo htmlspecialchars($this->plxMotor->aConf['title'].' - '.$this->plxMotor->aCats[ $this->plxMotor->cible ]['name'],ENT_QUOTES,PLX_CHARSET);
			return;
		}
		if($this->plxMotor->mode == 'article') {
			echo htmlspecialchars($this->plxMotor->plxRecord_arts->f('title').' - '.$this->plxMotor->aConf['title'],ENT_QUOTES,PLX_CHARSET);
			return;
		}
		if($this->plxMotor->mode == 'static') {
			echo htmlspecialchars($this->plxMotor->aConf['title'].' - '.$this->plxMotor->aStats[ $this->plxMotor->cible ]['name'],ENT_QUOTES,PLX_CHARSET);
			return;
		}
		if($this->plxMotor->mode == 'erreur') {
			echo htmlspecialchars($this->plxMotor->aConf['title'],ENT_QUOTES,PLX_CHARSET).' - '.$this->plxMotor->plxErreur->getMessage();
			return;
		}
	}

	/**
	 * Mthode qui affiche le titre du blog link (variable $type='link') ou non
	 *
	 * @param	type	type d'affichage : link => sous forme de lien
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function mainTitle($type='') {

		$title = htmlspecialchars($this->plxMotor->aConf['title'],ENT_QUOTES,PLX_CHARSET);
		if($type == 'link') # Type lien
			echo '<a href="./" title="'.$title.'">'.$title.'</a>';
		else # Type normal
			echo $title;
	}

	/**
	 * Mthode qui affiche le sous-titre du blog
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function subTitle() {

		echo htmlspecialchars($this->plxMotor->aConf['description'],ENT_QUOTES,PLX_CHARSET);
	}

	/**
	 * Mthode qui affiche le nombre de catgories actives du site.
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function nbAllCat() {

		# Initialisation
		$nb = 0;
		# On verifie qu'il y a des categories
		if($this->plxMotor->aCats) {
			foreach($this->plxMotor->aCats as $k=>$v) {
				if($v['articles'] > 0) # On a des articles
					$nb++;
			} # Fin du while
		}
		# On procde  l'affichage
		if($nb < 2)
			echo $nb.' cat&eacute;gorie';
		else
			echo $nb.' cat&eacute;gories';
	}

	/**
	 * Mthode qui affiche le nombre d'articles du site.
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function nbAllArt() {

		# Initialisation
		$nb = 0;
		# Nouvel objet pour compter le nombre d'articles
		$plxGlob_arts = & new plxGlob(PLX_ROOT.$this->plxMotor->aConf['racine_articles']);
		$plxGlob_arts->query('/^[0-9]{4}.[0-9]{3}.(.+).xml$/');
		$nb = $plxGlob_arts->count;
		# On procde  l'affichage
		if($nb < 2)
			echo $nb.' article';
		else
			echo $nb.' articles';
	}

	/**
	 * Mthode qui affiche le nombre de commentaires du site.
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function nbAllCom() {

		# Initialisation
		$nb = 0;
		# Nouvel objet pour compter le nombre de commentaires
		$plxGlob_coms = & new plxGlob(PLX_ROOT.$this->plxMotor->aConf['racine_commentaires']);
		$plxGlob_coms->query('/^[0-9]{4}.[0-9]{10}-[0-9]+.xml$/');
		$nb = $plxGlob_coms->count;
		# On procde  l'affichage
		if($nb < 2)
			echo $nb.' commentaire';
		else
			echo $nb.' commentaires';
		}

	/**
	 * Mthode qui affiche la liste des pages statiques.
	 * Si la variable $extra est renseigne, un lien vers la 
	 * page d'accueil (nomm $extra) sera mis en place en premire 
	 * position
	 *
	 * @param	extra	nom du lien vers la page d'accueil
	 * @return	stdout
	 * @author	Florent MONTHEL, Stephane F.
	 **/
	function staticList($extra='') {

		# Si on a la variable extra, on affiche un lien vers la page d'accueil
		if($extra != '')
			echo '<li><a href="./" title="'.htmlspecialchars($this->plxMotor->aConf['title'],ENT_QUOTES,PLX_CHARSET).'">'.$extra.'</a></li>';
		# On verifie qu'il y a des pages statiques
		if($this->plxMotor->aStats) {
			foreach($this->plxMotor->aStats as $k=>$v) {
				if($v['readable'] == 1 AND $v['active'] == 1) { # La page existe bien et elle est active
					$v['name'] = htmlspecialchars($v['name'],ENT_QUOTES,PLX_CHARSET);
					echo '<li><a href="./?static'.intval($k).'/'.$v['url'].'" title="'.$v['name'].'">'.$v['name'].'</a></li>';
				}
			} # Fin du while
		}
	}

	/**
	 * Mthode qui affiche la liste des catgories actives.
	 * Si la variable $extra est renseigne, un lien vers la 
	 * page d'accueil (nomm $extra) sera mis en place en premire 
	 * position
	 *
	 * @param	extra	nom du lien vers la page d'accueil
	 * @param	format du texte pour chaque categorie (variable : #cat_id,#cat_name,#art_nb)
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function catList($extra='', $format='#cat_name') {

		# Si on a la variable extra, on affiche un lien vers la page d'accueil (avec $extra comme nom)
		if($extra != '')
			echo '<li><a href="./" title="'.htmlspecialchars($this->plxMotor->aConf['title'],ENT_QUOTES,PLX_CHARSET).'">'.$extra.'</a></li>';
		# On verifie qu'il y a des categories
		if($this->plxMotor->aCats) {
			foreach($this->plxMotor->aCats as $k=>$v) {
				if($v['articles'] > 0) { # On a des articles
					$v['name'] = htmlspecialchars($v['name'],ENT_QUOTES,PLX_CHARSET);
					# On modifie nos motifs
					$stdout = str_replace('#cat_id',intval($k),$format);
					$stdout = str_replace('#cat_name',$v['name'],$stdout);
					$stdout = str_replace('#art_nb',$v['articles'],$stdout);
					# Ok
					echo '<li><a href="./?categorie'.intval($k).'/'.$v['url'].'" title="'.$v['name'].'">'.$stdout.'</a></li>';
				}
			} # Fin du while
		}
	}

	/**
	 * Mthode qui affiche l'id de la catgorie active (0 si non trouv)
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function catId() {

		# On va verifier que la categorie existe en mode categorie
		if($this->plxMotor->mode == 'categorie' AND isset($this->plxMotor->aCats[ $this->plxMotor->cible ]))
			echo intval($this->plxMotor->cible);
		# On va verifier que la categorie existe en mode article
		elseif($this->plxMotor->mode == 'article' AND isset($this->plxMotor->aCats[ $this->plxMotor->plxRecord_arts->f('categorie') ]))
			echo intval($this->plxMotor->plxRecord_arts->f('categorie'));
		else
			echo '0';
	}

	/**
	 * Mthode qui affiche le nom de la catgorie active (link ou non)
	 *
	 * @param	type	type d'affichage : link => sous forme de lien
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function catName($type='') {

		# On va verifier que la categorie existe en mode categorie
		if($this->plxMotor->mode == 'categorie' AND isset($this->plxMotor->aCats[ $this->plxMotor->cible ])) {
			# On recupere les infos de la categorie
			$id = $this->plxMotor->cible;
			$name = htmlspecialchars($this->plxMotor->aCats[ $id ]['name'],ENT_QUOTES,PLX_CHARSET);
			$url = $this->plxMotor->aCats[ $id ]['url'];
			# On effectue l'affichage
			if($type == 'link')
				echo '<a href="./?categorie'.intval($id).'/'.$url.'" title="'.$name.'">'.$name.'</a>';
			else
				echo $name;
		}
		# On va verifier que la categorie existe en mode article
		elseif($this->plxMotor->mode == 'article' AND isset($this->plxMotor->aCats[ $this->plxMotor->plxRecord_arts->f('categorie') ])) {
			# On recupere les infos de la categorie
			$id = $this->plxMotor->plxRecord_arts->f('categorie');
			$name = htmlspecialchars($this->plxMotor->aCats[ $id ]['name'],ENT_QUOTES,PLX_CHARSET);
			$url = $this->plxMotor->aCats[ $id ]['url'];
			# On effectue l'affichage
			if($type == 'link')
				echo '<a href="./?categorie'.intval($id).'/'.$url.'" title="'.$name.'">'.$name.'</a>';
			else
				echo $name;
		}
		# Mode home
		elseif($this->plxMotor->mode == 'home') {
			if($type == 'link')
				echo '<a href="./" title="'.htmlspecialchars($this->plxMotor->aConf['title'],ENT_QUOTES,PLX_CHARSET).'">Accueil</a>';
			else
				echo 'Accueil';
		} else {
			echo 'Non class&eacute;';
		}
	}

	/**
	 * Mthode qui retourne l'identifiant de l'article en question (sans les 0 supplmentaires)
	 *
	 * @return	int
	 * @author	Florent MONTHEL
	 **/
	function artId() {

		return intval($this->plxMotor->plxRecord_arts->f('numero'));
	}

	/**
	 * Mthode qui affiche le titre de l'article link (variable $type='link') ou non
	 *
	 * @param	type	type d'affichage : link => sous forme de lien
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artTitle($type='') {

		if($type == 'link') { # Type lien
			# On recupere les infos de l'article
			$num = $this->artId();
			$title = htmlspecialchars($this->plxMotor->plxRecord_arts->f('title'),ENT_QUOTES,PLX_CHARSET);
			$url = $this->plxMotor->plxRecord_arts->f('url');
			# On effectue l'affichage
			echo '<a href="./?article'.$num.'/'.$url.'" title="'.$title.'">'.$title.'</a>';
		} else { # Type normal
			echo htmlspecialchars($this->plxMotor->plxRecord_arts->f('title'),ENT_QUOTES,PLX_CHARSET);
		}
	}

	/**
	 * Mthode qui affiche l'auteur de l'article
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artAuthor() {

		echo htmlspecialchars($this->plxMotor->plxRecord_arts->f('author'),ENT_QUOTES,PLX_CHARSET);
	}

	/**
	 * Mthode qui affiche la date de publication de l'article 
	 * au format samedi 12 septembre 2009
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artDate() {

		echo plxUtils::dateIsoToHum($this->plxMotor->plxRecord_arts->f('date'));
	}

	/**
	 * Mthode qui affiche l'heure de publication de l'article 
	 * au format 12:45
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artHour() {

		echo plxUtils::heureIsoToHum($this->plxMotor->plxRecord_arts->f('date'));
	}

	/**
	 * Mthode qui affiche la catgorie link de l'article 
	 * ou la chane de caractre 'Non class' si la catgorie 
	 * de l'article n'existe pas
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artCat() {

		# Initialisation de notre variable interne
		$catId = $this->plxMotor->plxRecord_arts->f('categorie');
		# On verifie que la categorie n'est pas "home"
		if($catId != 'home') {
			# On va verifier que la categorie existe
			if(isset($this->plxMotor->aCats[ $catId ])) {
				# On recupere les infos de la categorie
				$name = htmlspecialchars($this->plxMotor->aCats[ $catId ]['name'],ENT_QUOTES,PLX_CHARSET);
				$url = $this->plxMotor->aCats[ $catId ]['url'];
				# On effectue l'affichage
				echo '<a href="./?categorie'.intval($catId).'/'.$url.'" title="'.$name.'">'.$name.'</a>';
			} else { # La categorie n'existe pas
				echo 'Non class&eacute;';
			}
		} else { # Categorie "home"
			echo '<a href="./" title="'.htmlspecialchars($this->plxMotor->aConf['title'],ENT_QUOTES,PLX_CHARSET).'">Accueil</a>';
		}
	}

	/**
	 * Mthode qui affiche le chpo de l'article ainsi qu'un lien 
	 * pour lire la suite de l'article. Si l'article n'a pas de chap, 
	 * le contenu de l'article est affich
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artChapo() {

		# On verifie qu'un chapo existe
		if($this->plxMotor->plxRecord_arts->f('chapo') != '') {
			# On recupere les infos de l'article
			$num = $this->artId();
			$title = htmlspecialchars($this->plxMotor->plxRecord_arts->f('title'),ENT_QUOTES,PLX_CHARSET);
			$url = $this->plxMotor->plxRecord_arts->f('url');
			# On effectue l'affichage
			echo $this->plxMotor->plxRecord_arts->f('chapo');
			echo '<p><a href="./?article'.$num.'/'.$url.'" title="Lire : '.$title.'">Lire : '.$title.'</a></p>'."\n";
		} else { # Pas de chapo, affichage du contenu
			echo $this->plxMotor->plxRecord_arts->f('content')."\n";
		}
	}

	/**
	 * Mthode qui affiche le chap suivi du contenu de l'article
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artContent() {

		echo $this->plxMotor->plxRecord_arts->f('chapo')."\n"; # Chapo
		echo $this->plxMotor->plxRecord_arts->f('content')."\n"; # Contenu
	}

	/**
	 * Mthode qui affiche un lien vers le fil RSS ou ATOM des articles
	 *
	 * @param	type	type de flux : rss ou atom
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artFeed($type='atom') {

		if($type == 'rss') # Type RSS
			echo '<a href="./feed.php?rss" title="Fil Rss des articles">Fil des articles</a>';
		else # Type ATOM
			echo '<a href="./feed.php?atom" title="Fil Atom des articles">Fil des articles</a>';
	}

	/**
	 * Mthode qui affiche le nombre de commentaires (sous forme de lien ou non selon le mode)
	 * d'un article
	 *
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function artNbCom() {

		# On recupre le nb de commentaire selon le mode
		if($this->plxMotor->mode == 'article')
			$nb = $this->plxMotor->plxGlob_coms->count;
		else
			$nb = $this->plxMotor->plxRecord_arts->f('nb_com');
		# A t'on besoin d'afficher le nb de commentaires ?
		if((!$this->plxMotor->aConf['allow_com'] OR !$this->plxMotor->plxRecord_arts->f('allow_com')) AND !$nb)
			return;
		# Petit test pour l'orthographe
		if($nb < 2)
			$txt = $nb.' commentaire';
		else
			$txt = $nb.' commentaires';
		# On effectue l'affichage selon le mode
		if($this->plxMotor->mode == 'article') {
			echo $txt;
		} else {
			# On recupere les infos de l'article
			$num = intval($this->plxMotor->plxRecord_arts->f('numero'));
			$title = htmlspecialchars($this->plxMotor->plxRecord_arts->f('title'),ENT_QUOTES,PLX_CHARSET);
			$url = $this->plxMotor->plxRecord_arts->f('url');
			# On effectue l'affichage
			echo '<a href="./?article'.$num.'/'.$url.'#comments" title="'.$txt.' pour '.$title.'">'.$txt.'</a>';
		}
	}

	/**
	 * Mthode qui affiche l'id du commentaire prcd d'un "c"
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function comId() {

		echo 'c'.$this->plxMotor->plxRecord_coms->f('numero');
	}

	/**
	 * Mthode qui affiche l'auteur du commentaires link
	 * ou non 
	 *
	 * @param	type	type d'affichage : link => sous forme de lien
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function comAuthor($type='') {

		# Initialisation de nos variables interne
		$author = $this->plxMotor->plxRecord_coms->f('author');
		$site = $this->plxMotor->plxRecord_coms->f('site');
		if($type == 'link' AND $site != '') # Type lien
			echo '<a href="'.$site.'" title="'.$author.'">'.$author.'</a>';
		else # Type normal
			echo $author;
	}

	/**
	 * Mthode qui affiche la date et l'heure de publication d'un commentaire
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function comDate() {

		echo plxUtils::dateIsoToHum($this->plxMotor->plxRecord_coms->f('date')).' &agrave; '.plxUtils::heureIsoToHum($this->plxMotor->plxRecord_coms->f('date'));
	}

	/**
	 * Mthode qui affiche le contenu d'un commentaire
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function comContent() {

		echo nl2br($this->plxMotor->plxRecord_coms->f('content'));
	}

	/**
	 * Mthode qui affiche si besoin le message gnr par le systme
	 * suite  la cration d'un commentaire
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function comMessage() {

		if($this->plxMotor->message_com) echo $this->plxMotor->message_com;
	}

	/**
	 * Mthode qui affiche si besoin la variable $_GET[$key] suite au dpt d'un commentaire
	 *
	 * @param	key	cl du tableau GET
	 * @param	defaut	valeur par dfaut si variable vide
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function comGet($key,$defaut='') {

		if(isset($_GET[$key]))
			echo htmlspecialchars(plxUtils::unSlash(urldecode(trim($_GET[$key]))),ENT_QUOTES,PLX_CHARSET);
		else
			echo $defaut;
	}

	/**
	 * Mthode qui affiche un lien vers le fil RSS ou ATOM des commentaires
	 * d'un article prcis (si $article renseign) ou du site tout entier
	 *
	 * @param	type	type de flux : rss ou atom
	 * @param	article	identifiant (sans les 0) d'un article
	 * @return	stdout
	 * @author	Anthony GURIN et Florent MONTHEL
	 **/
	function comFeed($type='atom',$article='') {

		if($type == 'rss' AND $article != '') # Fil RSS des commentaires d'un article
			echo '<a href="./feed.php?rss/commentaires/article'.$article.'" title="Fil Rss des commentaires de cet article">Fil des commentaires de cet article</a>';
		elseif($type == 'rss') # Fil RSS des commentaires global
			echo '<a href="./feed.php?rss/commentaires" title="Fil Rss global des commentaires">Fil des commentaires</a>';
		elseif(	$article != '') # Fil ATOM des commentaires d'un article
			echo '<a href="./feed.php?atom/commentaires/article'.$article.'" title="Fil Atom des commentaires de cet article">Fil des commentaires de cet article</a>';
		else # Fil ATOM des commentaires global
			echo '<a href="./feed.php?atom/commentaires" title="Fil Atom global des commentaires">Fil des commentaires</a>';
	}

	/**
	 * Mthode qui affiche le titre de la page statique
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function staticTitle() {

		echo htmlspecialchars($this->plxMotor->aStats[ $this->plxMotor->cible ]['name'],ENT_QUOTES,PLX_CHARSET);
	}

	/**
	 * Mthode qui inclut le code source de la page statique
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function staticContent() {

		# On genere le nom du fichier a inclure
		$file = PLX_ROOT.$this->plxMotor->aConf['racine_statiques'].$this->plxMotor->cible;
		$file .= '.'.$this->plxMotor->aStats[ $this->plxMotor->cible ]['url'].'.php';
		# Inclusion du fichier
		require $file;
	}

	/**
	 * Mthode qui affiche la pagination
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function pagination() {

		# On verifie que la variable bypage n'est pas nulle
		if($this->plxMotor->bypage) {
			# Calcul des pages
			$prev_page = $this->plxMotor->page - 1;
			$next_page = $this->plxMotor->page + 1;
			$last_page = ceil($this->plxMotor->plxGlob_arts->count/$this->plxMotor->bypage);
			if($this->plxMotor->mode == 'home') { # En mode home
				# Generation des URLs
				$p_url = './?page'.$prev_page; # Page precedente
				$n_url = './?page'.$next_page; # Page suivante
				$l_url = './?page'.$last_page; # Derniere page
				$f_url = './'; # Premiere page
			} elseif($this->plxMotor->mode == 'categorie') { # En mode categorie
				# Generation des URLs
				$get = explode('/',$this->plxMotor->get);
				$p_url = './?'.$get[0].'/'.$get[1].'/page'.$prev_page; # Page precedente
				$n_url = './?'.$get[0].'/'.$get[1].'/page'.$next_page; # Page suivante
				$l_url = './?'.$get[0].'/'.$get[1].'/page'.$last_page; # Derniere page
				$f_url = './?'.$get[0].'/'.$get[1]; # Premiere page
			}
			# On effectue l'affichage
			if($this->plxMotor->page > 2) # Si la page active > 2 on affiche un lien 1ere page
				echo '<a href="'.$f_url.'" title="Aller  la premi&egrave;re page">&lt;&lt;</a> | ';
			if($this->plxMotor->page > 1) # Si la page active > 1 on affiche un lien page precedente
				echo '<a href="'.$p_url.'" title="Page pr&eacute;c&eacute;dente">&lt; pr&eacute;c&eacute;dente</a> | ';
			# Affichage de la page courante
			echo 'page '.$this->plxMotor->page.' sur '.$last_page;
			if($this->plxMotor->page < $last_page) # Si la page active < derniere page on affiche un lien page suivante
				echo ' | <a href="'.$n_url.'" title="Page suivante">suivante &gt;</a>';
			if(($this->plxMotor->page + 1) < $last_page) # Si la page active++ < derniere page on affiche un lien derniere page
				echo ' | <a href="'.$l_url.'" title="Aller  la derni&egrave;re page">&gt;&gt;</a>';
		}
	}

	/**
	 * Mthode qui affiche la question du capcha
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function capchaQ() {

		echo $this->plxMotor->plxCapcha->q();
	}

	/**
	 * Mthode qui affiche la rponse du capcha crypte en MD5
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function capchaR() {

		echo $this->plxMotor->plxCapcha->r();
	}

	/**
	 * Mthode qui affiche le message d'erreur de l'objet plxErreur
	 *
	 * @return	stdout
	 * @author	Florent MONTHEL
	 **/
	function erreurMessage() {

		echo $this->plxMotor->plxErreur->message;
	}	

}
?>